Translate Toolkit - documentation

The Translate Toolkit is a set of tools designed to work with XLIFF and Gettext PO files, and can manipulate several other formats.

The Toolkit provides a platform for developing localisation tools and is used as such a platform by the following projects:

- Virtaal
- Pootle
- Open-Tran.eu - providing translation memory lookup

The Translate Toolkit is hosted at translate.sourceforge.net.

The documentation packaged with the Translate Toolkit have two parts:

- User documentation
- API documentation (for programmers)

The most up-to-date documentation about the Translate Toolkit is available online in the Translate wiki. Please contribute any improvements there.